@@ -213,7 +213,10 @@ display_show (GtkSourceCompletion *self)
 		self->hide_tick_handler = 0;
 	}
 
-	gtk_widget_show (GTK_WIDGET (_gtk_source_completion_get_display (self)));
+	if (gtk_widget_get_mapped (GTK_WIDGET (self->view)))
+	{
+		gtk_widget_show (GTK_WIDGET (_gtk_source_completion_get_display (self)));
+	}
 }
 
 static gboolean
@@ -473,7 +476,8 @@ gtk_source_completion_compute_bounds (GtkSourceCompletion *self,
 
 static void
 gtk_source_completion_start (GtkSourceCompletion           *self,
-                             GtkSourceCompletionActivation  activation)
+                             GtkSourceCompletionActivation  activation,
+                             gboolean                       from_trigger)
 {
 	GtkSourceCompletionContext *context = NULL;
 	GtkTextBuffer *buffer;
@@ -487,8 +491,11 @@ gtk_source_completion_start (GtkSourceCompletion           *self,
 
 	if (!gtk_source_completion_compute_bounds (self, &begin, &end))
 	{
-		if (activation == GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE)
+		if (!from_trigger && activation == GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE)
+		{
 			goto cleanup;
+		}
+
 		begin = end;
 	}
 
@@ -531,7 +538,8 @@ cleanup:
 
 static void
 gtk_source_completion_update (GtkSourceCompletion           *self,
-                              GtkSourceCompletionActivation  activation)
+                              GtkSourceCompletionActivation  activation,
+                              gboolean                       from_trigger)
 {
 	GtkTextBuffer *buffer;
 	GtkTextMark *insert;
@@ -616,7 +624,7 @@ gtk_source_completion_update (GtkSourceCompletion           *self,
 
 reset:
 	gtk_source_completion_cancel (self);
-	gtk_source_completion_start (self, activation);
+	gtk_source_completion_start (self, activation, from_trigger);
 }
 
 static void
@@ -639,14 +647,14 @@ gtk_source_completion_real_show (GtkSourceCompletion *self)
 
 	display = _gtk_source_completion_get_display (self);
 
-	if (self->context == NULL)
-	{
-		gtk_source_completion_start (self, GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED);
-	}
-	else
-	{
-		gtk_source_completion_update (self, GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED);
-	}
+	/* If the user is requesting completion manually, we should throw away
+	 * our previous results and attempt completion over. Otherwise, providers
+	 * which bailed because they were in _INTERACTIVE_ mode will not be
+	 * requeried for updated results.
+	 */
+	g_clear_object (&self->context);
+
+	gtk_source_completion_start (self, GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED, FALSE);
 
 	_gtk_source_completion_list_set_context (display, self->context);
 
@@ -670,7 +678,9 @@ gtk_source_completion_queued_update_cb (gpointer user_data)
 	self->queued_update = 0;
 
 	if (self->context != NULL)
-		gtk_source_completion_update (self, GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE);
+	{
+		gtk_source_completion_update (self, GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE, FALSE);
+	}
 
 	return G_SOURCE_REMOVE;
 }
@@ -803,7 +813,8 @@ gtk_source_completion_buffer_insert_text_after_cb (GtkSourceCompletion *self,
                                                    gint                 len,
                                                    GtkTextBuffer       *buffer)
 {
-	GtkSourceCompletionActivation activation = GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE;
+	const GtkSourceCompletionActivation activation = GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE;
+	gboolean from_trigger = FALSE;
 	GtkTextIter begin;
 	GtkTextIter end;
 
@@ -840,8 +851,8 @@ gtk_source_completion_buffer_insert_text_after_cb (GtkSourceCompletion *self,
 					 * completion. We need to cancel the previous completion (if any) first
 					 * and then try to start a new completion due to trigger.
 					 */
+					from_trigger = TRUE;
 					gtk_source_completion_cancel (self);
-					activation = GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE;
 					goto do_completion;
 				}
 			}
@@ -854,9 +865,9 @@ gtk_source_completion_buffer_insert_text_after_cb (GtkSourceCompletion *self,
 do_completion:
 
 	if (self->context == NULL)
-		gtk_source_completion_start (self, activation);
+		gtk_source_completion_start (self, activation, from_trigger);
 	else
-		gtk_source_completion_update (self, activation);
+		gtk_source_completion_update (self, activation, from_trigger);
 }
 
 static void
