@@ -33,21 +33,21 @@
 #include "gtksourcetrace.h"
 
 /**
- * SECTION:printcompositor
- * @Short_description: Compose a GtkSourceBuffer for printing
- * @Title: GtkSourcePrintCompositor
+ * GtkSourcePrintCompositor:
+ * 
+ * Compose a [class@Buffer] for printing.
  *
- * The #GtkSourcePrintCompositor object is used to compose a #GtkSourceBuffer
+ * The `GtkSourcePrintCompositor` object is used to compose a [class@Buffer]
  * for printing. You can set various configuration options to customize the
- * printed output. #GtkSourcePrintCompositor is designed to be used with the
- * high-level printing API of gtk+, i.e. #GtkPrintOperation.
+ * printed output. `GtkSourcePrintCompositor` is designed to be used with the
+ * high-level printing API of gtk+, i.e. [class@Gtk.PrintOperation].
  *
  * The margins specified in this object are the layout margins: they define the
  * blank space bordering the printed area of the pages. They must not be
  * confused with the "print margins", i.e. the parts of the page that the
- * printer cannot print on, defined in the #GtkPageSetup objects. If the
+ * printer cannot print on, defined in the [class@Gtk.PageSetup] objects. If the
  * specified layout margins are smaller than the "print margins", the latter
- * ones are used as a fallback by the #GtkSourcePrintCompositor object, so that
+ * ones are used as a fallback by the `GtkSourcePrintCompositor` object, so that
  * the printed area is not clipped.
  */
 
@@ -154,6 +154,8 @@ typedef struct
 
 	GtkTextMark             *pagination_mark;
 
+	GHashTable              *ignored_tags;
+
 #ifdef GTK_SOURCE_PROFILER_ENABLED
 	gint64                   pagination_timer;
 #endif
@@ -305,6 +307,15 @@ gtk_source_print_compositor_set_property (GObject      *object,
 	{
 		case PROP_BUFFER:
 			priv->buffer = GTK_SOURCE_BUFFER (g_value_dup_object (value));
+			if (priv->buffer)
+			{
+				GtkTextTag *tag = _gtk_source_buffer_get_bracket_match_tag (priv->buffer);
+
+				if (tag)
+				{
+					gtk_source_print_compositor_ignore_tag (compositor, tag);
+				}
+			}
 			break;
 		case PROP_TAB_WIDTH:
 			gtk_source_print_compositor_set_tab_width (compositor,
@@ -357,6 +368,8 @@ gtk_source_print_compositor_finalize (GObject *object)
 	GtkSourcePrintCompositor *compositor = GTK_SOURCE_PRINT_COMPOSITOR (object);
 	GtkSourcePrintCompositorPrivate *priv = gtk_source_print_compositor_get_instance_private (compositor);
 
+	g_clear_pointer (&priv->ignored_tags, g_hash_table_unref);
+
 	if (priv->pages != NULL)
 		g_array_free (priv->pages, TRUE);
 
@@ -419,9 +432,7 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	/**
 	 * GtkSourcePrintCompositor:buffer:
 	 *
-	 * The GtkSourceBuffer object to print.
-	 *
-	 * Since: 2.2
+	 * The [class@Buffer] object to print.
 	 */
 	properties[PROP_BUFFER] =
 		g_param_spec_object ("buffer",
@@ -438,9 +449,7 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * Width of a tab character expressed in spaces.
 	 *
 	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_TAB_WIDTH] =
 		g_param_spec_uint ("tab-width",
@@ -460,9 +469,7 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * Whether to wrap lines never, at word boundaries, or at character boundaries.
 	 *
  	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_WRAP_MODE] =
 		g_param_spec_enum ("wrap-mode",
@@ -480,9 +487,7 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * Whether to print the document with highlighted syntax.
 	 *
  	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_HIGHLIGHT_SYNTAX] =
 		g_param_spec_boolean ("highlight-syntax",
@@ -496,14 +501,14 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	/**
 	 * GtkSourcePrintCompositor:print-line-numbers:
 	 *
-	 * Interval of printed line numbers. If this property is set to 0 no
-	 * numbers will be printed.  If greater than 0, a number will be
- 	 * printed every "print-line-numbers" lines (i.e. 1 will print all line numbers).
+	 * Interval of printed line numbers. 
+	 * 
+	 * If this property is set to 0 no numbers will be printed.
+	 * If greater than 0, a number will be printed every "print-line-numbers"
+	 * lines (i.e. 1 will print all line numbers).
 	 *
 	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_PRINT_LINE_NUMBERS] =
 		g_param_spec_uint ("print-line-numbers",
@@ -524,9 +529,7 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * this property.
 	 *
 	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_PRINT_HEADER] =
 		g_param_spec_boolean ("print-header",
@@ -547,9 +550,7 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * this property.
 	 *
 	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_PRINT_FOOTER] =
 		g_param_spec_boolean ("print-footer",
@@ -566,13 +567,11 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * Name of the font used for the text body.
 	 *
 	 * Accepted values are strings representing a font description Pango can understand.
-	 * (e.g. &quot;Monospace 10&quot;). See pango_font_description_from_string()
+	 * (e.g. &quot;Monospace 10&quot;). See [func@Pango.FontDescription.from_string]
 	 * for a description of the format of the string representation.
 	 *
 	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_BODY_FONT_NAME] =
 		g_param_spec_string ("body-font-name",
@@ -590,13 +589,11 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * If this property is unspecified, the text body font is used.
 	 *
 	 * Accepted values are strings representing a font description Pango can understand.
-	 * (e.g. &quot;Monospace 10&quot;). See pango_font_description_from_string()
+	 * (e.g. &quot;Monospace 10&quot;). See [func@Pango.FontDescription.from_string]
 	 * for a description of the format of the string representation.
 	 *
 	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_LINE_NUMBERS_FONT_NAME] =
 		g_param_spec_string ("line-numbers-font-name",
@@ -614,13 +611,11 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * If this property is unspecified, the text body font is used.
 	 *
 	 * Accepted values are strings representing a font description Pango can understand.
-	 * (e.g. &quot;Monospace 10&quot;). See pango_font_description_from_string()
+	 * (e.g. &quot;Monospace 10&quot;). See [func@Pango.FontDescription.from_string]
 	 * for a description of the format of the string representation.
 	 *
 	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_HEADER_FONT_NAME] =
 		g_param_spec_string ("header-font-name",
@@ -638,13 +633,11 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 * If this property is unspecified, the text body font is used.
 	 *
 	 * Accepted values are strings representing a font description Pango can understand.
-	 * (e.g. &quot;Monospace 10&quot;). See pango_font_description_from_string()
+	 * (e.g. &quot;Monospace 10&quot;). See [func@Pango.FontDescription.from_string]
 	 * for a description of the format of the string representation.
 	 *
 	 * The value of this property cannot be changed anymore after the first
-	 * call to the gtk_source_print_compositor_paginate() function.
-	 *
-	 * Since: 2.2
+	 * call to the [method@PrintCompositor.paginate] function.
 	 */
 	properties [PROP_FOOTER_FONT_NAME] =
 		g_param_spec_string ("footer-font-name",
@@ -660,8 +653,6 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 	 *
 	 * The number of pages in the document or <code>-1</code> if the
  	 * document has not been completely paginated.
- 	 *
- 	 * Since: 2.2
  	 */
 	properties [PROP_N_PAGES] =
 		g_param_spec_int ("n-pages",
@@ -680,6 +671,7 @@ gtk_source_print_compositor_init (GtkSourcePrintCompositor *compositor)
 	GtkSourcePrintCompositorPrivate *priv = gtk_source_print_compositor_get_instance_private (compositor);
 
 	priv->buffer = NULL;
+	priv->ignored_tags = g_hash_table_new (NULL, NULL);
 
 	priv->tab_width = DEFAULT_TAB_WIDTH;
 	priv->wrap_mode = GTK_WRAP_NONE;
@@ -739,8 +731,6 @@ gtk_source_print_compositor_init (GtkSourcePrintCompositor *compositor)
  * Creates a new print compositor that can be used to print @buffer.
  *
  * Return value: a new print compositor object.
- *
- * Since: 2.2
  **/
 GtkSourcePrintCompositor *
 gtk_source_print_compositor_new (GtkSourceBuffer *buffer)
@@ -758,15 +748,14 @@ gtk_source_print_compositor_new (GtkSourceBuffer *buffer)
  *
  * Creates a new print compositor that can be used to print the buffer
  * associated with @view.
+ *
  * This constructor sets some configuration properties to make the
  * printed output match @view as much as possible.  The properties set are
- * #GtkSourcePrintCompositor:tab-width, #GtkSourcePrintCompositor:highlight-syntax,
- * #GtkSourcePrintCompositor:wrap-mode, #GtkSourcePrintCompositor:body-font-name and
- * #GtkSourcePrintCompositor:print-line-numbers.
+ * [property@PrintCompositor:tab-width], [property@PrintCompositor:highlight-syntax],
+ * [property@PrintCompositor:wrap-mode], [property@PrintCompositor:body-font-name] and
+ * [property@PrintCompositor:print-line-numbers].
  *
  * Return value: a new print compositor object.
- *
- * Since: 2.2
  **/
 GtkSourcePrintCompositor *
 gtk_source_print_compositor_new_from_view (GtkSourceView *view)
@@ -806,13 +795,12 @@ gtk_source_print_compositor_new_from_view (GtkSourceView *view)
  * gtk_source_print_compositor_get_buffer:
  * @compositor: a #GtkSourcePrintCompositor.
  *
- * Gets the #GtkSourceBuffer associated with the compositor. The returned
- * object reference is owned by the compositor object and
+ * Gets the [class@Buffer] associated with the compositor. 
+ * 
+ * The returned object reference is owned by the compositor object and
  * should not be unreferenced.
  *
  * Return value: (transfer none): the #GtkSourceBuffer associated with the compositor.
- *
- * Since: 2.2
  **/
 GtkSourceBuffer *
 gtk_source_print_compositor_get_buffer (GtkSourcePrintCompositor *compositor)
@@ -832,9 +820,7 @@ gtk_source_print_compositor_get_buffer (GtkSourcePrintCompositor *compositor)
  * Sets the width of tabulation in characters for printed text.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  */
 void
 gtk_source_print_compositor_set_tab_width (GtkSourcePrintCompositor *compositor,
@@ -862,8 +848,6 @@ gtk_source_print_compositor_set_tab_width (GtkSourcePrintCompositor *compositor,
  * Returns the width of tabulation in characters for printed text.
  *
  * Return value: width of tab.
- *
- * Since: 2.2
  */
 guint
 gtk_source_print_compositor_get_tab_width (GtkSourcePrintCompositor *compositor)
@@ -883,9 +867,7 @@ gtk_source_print_compositor_get_tab_width (GtkSourcePrintCompositor *compositor)
  * Sets the line wrapping mode for the printed text.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  */
 void
 gtk_source_print_compositor_set_wrap_mode (GtkSourcePrintCompositor *compositor,
@@ -912,8 +894,6 @@ gtk_source_print_compositor_set_wrap_mode (GtkSourcePrintCompositor *compositor,
  * Gets the line wrapping mode for the printed text.
  *
  * Return value: the line wrap mode.
- *
- * Since: 2.2
  */
 GtkWrapMode
 gtk_source_print_compositor_get_wrap_mode (GtkSourcePrintCompositor *compositor)
@@ -934,9 +914,7 @@ gtk_source_print_compositor_get_wrap_mode (GtkSourcePrintCompositor *compositor)
  * buffer rules.  Both color and font style are applied.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  **/
 void
 gtk_source_print_compositor_set_highlight_syntax (GtkSourcePrintCompositor *compositor,
@@ -963,12 +941,11 @@ gtk_source_print_compositor_set_highlight_syntax (GtkSourcePrintCompositor *comp
  * @compositor: a #GtkSourcePrintCompositor.
  *
  * Determines whether the printed text will be highlighted according to the
- * buffer rules.  Note that highlighting will happen
- * only if the buffer to print has highlighting activated.
+ * buffer rules. 
+ *
+ * Note that highlighting will happen only if the buffer to print has highlighting activated.
  *
  * Return value: %TRUE if the printed output will be highlighted.
- *
- * Since: 2.2
  **/
 gboolean
 gtk_source_print_compositor_get_highlight_syntax (GtkSourcePrintCompositor *compositor)
@@ -985,16 +962,15 @@ gtk_source_print_compositor_get_highlight_syntax (GtkSourcePrintCompositor *comp
  * @compositor: a #GtkSourcePrintCompositor.
  * @interval: interval for printed line numbers.
  *
- * Sets the interval for printed line numbers.  If @interval is 0 no
- * numbers will be printed.  If greater than 0, a number will be
+ * Sets the interval for printed line numbers. 
+ * 
+ * If @interval is 0 no numbers will be printed. If greater than 0, a number will be
  * printed every @interval lines (i.e. 1 will print all line numbers).
  *
  * Maximum accepted value for @interval is 100.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  **/
 void
 gtk_source_print_compositor_set_print_line_numbers (GtkSourcePrintCompositor *compositor,
@@ -1020,18 +996,16 @@ gtk_source_print_compositor_set_print_line_numbers (GtkSourcePrintCompositor *co
  * @compositor: a #GtkSourcePrintCompositor.
  * @print: %TRUE if you want the header to be printed.
  *
- * Sets whether you want to print a header in each page.  The
- * header consists of three pieces of text and an optional line
- * separator, configurable with
- * gtk_source_print_compositor_set_header_format().
+ * Sets whether you want to print a header in each page.
+ * 
+ * The header consists of three pieces of text and an optional line
+ * separator, configurable with [method@PrintCompositor.set_header_format].
  *
  * Note that by default the header format is unspecified, and if it's
  * empty it will not be printed, regardless of this setting.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  **/
 void
 gtk_source_print_compositor_set_print_header (GtkSourcePrintCompositor *compositor,
@@ -1057,14 +1031,13 @@ gtk_source_print_compositor_set_print_header (GtkSourcePrintCompositor *composit
  * gtk_source_print_compositor_get_print_header:
  * @compositor: a #GtkSourcePrintCompositor.
  *
- * Determines if a header is set to be printed for each page.  A
- * header will be printed if this function returns %TRUE
- * <emphasis>and</emphasis> some format strings have been specified
- * with gtk_source_print_compositor_set_header_format().
+ * Determines if a header is set to be printed for each page. 
+ * 
+ * A header will be printed if this function returns %TRUE
+ * **and** some format strings have been specified
+ * with [method@PrintCompositor.set_header_format].
  *
  * Return value: %TRUE if the header is set to be printed.
- *
- * Since: 2.2
  **/
 gboolean
 gtk_source_print_compositor_get_print_header (GtkSourcePrintCompositor *compositor)
@@ -1081,18 +1054,17 @@ gtk_source_print_compositor_get_print_header (GtkSourcePrintCompositor *composit
  * @compositor: a #GtkSourcePrintCompositor.
  * @print: %TRUE if you want the footer to be printed.
  *
- * Sets whether you want to print a footer in each page.  The
- * footer consists of three pieces of text and an optional line
+ * Sets whether you want to print a footer in each page.
+ * 
+ * The footer consists of three pieces of text and an optional line
  * separator, configurable with
- * gtk_source_print_compositor_set_footer_format().
+ * [method@PrintCompositor.set_footer_format].
  *
  * Note that by default the footer format is unspecified, and if it's
  * empty it will not be printed, regardless of this setting.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  **/
 void
 gtk_source_print_compositor_set_print_footer (GtkSourcePrintCompositor *compositor,
@@ -1118,14 +1090,13 @@ gtk_source_print_compositor_set_print_footer (GtkSourcePrintCompositor *composit
  * gtk_source_print_compositor_get_print_footer:
  * @compositor: a #GtkSourcePrintCompositor.
  *
- * Determines if a footer is set to be printed for each page.  A
- * footer will be printed if this function returns %TRUE
- * <emphasis>and</emphasis> some format strings have been specified
- * with gtk_source_print_compositor_set_footer_format().
+ * Determines if a footer is set to be printed for each page. 
+ * 
+ * A footer will be printed if this function returns %TRUE
+ * **and** some format strings have been specified
+ * with [method@PrintCompositor.set_footer_format].
  *
  * Return value: %TRUE if the footer is set to be printed.
- *
- * Since: 2.2
  **/
 gboolean
 gtk_source_print_compositor_get_print_footer (GtkSourcePrintCompositor *compositor)
@@ -1146,11 +1117,13 @@ gtk_source_print_compositor_get_print_footer (GtkSourcePrintCompositor *composit
  * @right: (nullable): a format string to print on the right of the header.
  *
  * Sets strftime like header format strings, to be printed on the
- * left, center and right of the top of each page.  The strings may
- * include strftime(3) codes which will be expanded at print time.
- * A subset of strftime() codes are accepted, see g_date_time_format()
+ * left, center and right of the top of each page. 
+ * 
+ * The strings may include strftime(3) codes which will be expanded at print time.
+ * A subset of strftime() codes are accepted, see [method@GLib.DateTime.format]
  * for more details on the accepted format specifiers.
  * Additionally the following format specifiers are accepted:
+ *
  * - #N: the page number
  * - #Q: the page count.
  *
@@ -1162,12 +1135,10 @@ gtk_source_print_compositor_get_print_footer (GtkSourcePrintCompositor *composit
  *
  * For the header to be printed, in
  * addition to specifying format strings, you need to enable header
- * printing with gtk_source_print_compositor_set_print_header().
+ * printing with [method@PrintCompositor.set_print_header].
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  **/
 void
 gtk_source_print_compositor_set_header_format (GtkSourcePrintCompositor *compositor,
@@ -1201,10 +1172,8 @@ gtk_source_print_compositor_set_header_format (GtkSourcePrintCompositor *composi
  * @center: (nullable): a format string to print on the center of the footer.
  * @right: (nullable): a format string to print on the right of the footer.
  *
- * See gtk_source_print_compositor_set_header_format() for more information
+ * See [method@PrintCompositor.set_header_format] for more information
  * about the parameters.
- *
- * Since: 2.2
  **/
 void
 gtk_source_print_compositor_set_footer_format (GtkSourcePrintCompositor *compositor,
@@ -1234,13 +1203,12 @@ gtk_source_print_compositor_set_footer_format (GtkSourcePrintCompositor *composi
  * gtk_source_print_compositor_get_print_line_numbers:
  * @compositor: a #GtkSourcePrintCompositor.
  *
- * Returns the interval used for line number printing.  If the
- * value is 0, no line numbers will be printed.  The default value is
+ * Returns the interval used for line number printing.
+ *
+ * If the value is 0, no line numbers will be printed. The default value is
  * 1 (i.e. numbers printed in all lines).
  *
  * Return value: the interval of printed line numbers.
- *
- * Since: 2.2
  **/
 guint
 gtk_source_print_compositor_get_print_line_numbers (GtkSourcePrintCompositor *compositor)
@@ -1293,13 +1261,11 @@ set_font_description_from_name (GtkSourcePrintCompositor  *compositor,
  *
  * @font_name should be a
  * string representation of a font description Pango can understand.
- * (e.g. &quot;Monospace 10&quot;). See pango_font_description_from_string()
+ * (e.g. &quot;Monospace 10&quot;). See [func@Pango.FontDescription.from_string]
  * for a description of the format of the string representation.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  */
 void
 gtk_source_print_compositor_set_body_font_name (GtkSourcePrintCompositor *compositor,
@@ -1324,13 +1290,12 @@ gtk_source_print_compositor_set_body_font_name (GtkSourcePrintCompositor *compos
  * gtk_source_print_compositor_get_body_font_name:
  * @compositor: a #GtkSourcePrintCompositor.
  *
- * Returns the name of the font used to print the text body. The returned string
- * must be freed with g_free().
+ * Returns the name of the font used to print the text body. 
+ * 
+ * The returned string must be freed with g_free().
  *
  * Return value: a new string containing the name of the font used to print the
  * text body.
- *
- * Since: 2.2
  */
 gchar *
 gtk_source_print_compositor_get_body_font_name (GtkSourcePrintCompositor *compositor)
@@ -1347,19 +1312,18 @@ gtk_source_print_compositor_get_body_font_name (GtkSourcePrintCompositor *compos
  * @compositor: a #GtkSourcePrintCompositor.
  * @font_name: (nullable): the name of the font for line numbers, or %NULL.
  *
- * Sets the font for printing line numbers on the left margin.  If
- * %NULL is supplied, the default font (i.e. the one being used for the
+ * Sets the font for printing line numbers on the left margin.
+ * 
+ * If %NULL is supplied, the default font (i.e. the one being used for the
  * text) will be used instead.
  *
  * @font_name should be a
  * string representation of a font description Pango can understand.
- * (e.g. &quot;Monospace 10&quot;). See pango_font_description_from_string()
+ * (e.g. &quot;Monospace 10&quot;). See [func@Pango.FontDescription.from_string]
  * for a description of the format of the string representation.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  */
 void
 gtk_source_print_compositor_set_line_numbers_font_name (GtkSourcePrintCompositor *compositor,
@@ -1385,12 +1349,11 @@ gtk_source_print_compositor_set_line_numbers_font_name (GtkSourcePrintCompositor
  * @compositor: a #GtkSourcePrintCompositor.
  *
  * Returns the name of the font used to print line numbers on the left margin.
+ *
  * The returned string must be freed with g_free().
  *
  * Return value: a new string containing the name of the font used to print
  * line numbers on the left margin.
- *
- * Since: 2.2
  */
 gchar *
 gtk_source_print_compositor_get_line_numbers_font_name (GtkSourcePrintCompositor *compositor)
@@ -1413,19 +1376,18 @@ gtk_source_print_compositor_get_line_numbers_font_name (GtkSourcePrintCompositor
  * @compositor: a #GtkSourcePrintCompositor.
  * @font_name: (nullable): the name of the font for header text, or %NULL.
  *
- * Sets the font for printing the page header. If
- * %NULL is supplied, the default font (i.e. the one being used for the
+ * Sets the font for printing the page header. 
+ *
+ * If %NULL is supplied, the default font (i.e. the one being used for the
  * text) will be used instead.
  *
  * @font_name should be a
  * string representation of a font description Pango can understand.
- * (e.g. &quot;Monospace 10&quot;). See pango_font_description_from_string()
+ * (e.g. &quot;Monospace 10&quot;). See [func@Pango.FontDescription.from_string]
  * for a description of the format of the string representation.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  */
 void
 gtk_source_print_compositor_set_header_font_name (GtkSourcePrintCompositor *compositor,
@@ -1452,12 +1414,11 @@ gtk_source_print_compositor_set_header_font_name (GtkSourcePrintCompositor *comp
  * @compositor: a #GtkSourcePrintCompositor.
  *
  * Returns the name of the font used to print the page header.
+ *
  * The returned string must be freed with g_free().
  *
  * Return value: a new string containing the name of the font used to print
  * the page header.
- *
- * Since: 2.2
  */
 gchar *
 gtk_source_print_compositor_get_header_font_name (GtkSourcePrintCompositor *compositor)
@@ -1480,19 +1441,18 @@ gtk_source_print_compositor_get_header_font_name (GtkSourcePrintCompositor *comp
  * @compositor: a #GtkSourcePrintCompositor.
  * @font_name: (nullable): the name of the font for the footer text, or %NULL.
  *
- * Sets the font for printing the page footer. If
- * %NULL is supplied, the default font (i.e. the one being used for the
+ * Sets the font for printing the page footer. 
+ * 
+ * If %NULL is supplied, the default font (i.e. the one being used for the
  * text) will be used instead.
  *
  * @font_name should be a
  * string representation of a font description Pango can understand.
- * (e.g. &quot;Monospace 10&quot;). See pango_font_description_from_string()
+ * (e.g. &quot;Monospace 10&quot;). See [func@Pango.FontDescription.from_string]
  * for a description of the format of the string representation.
  *
  * This function cannot be called anymore after the first call to the
- * gtk_source_print_compositor_paginate() function.
- *
- * Since: 2.2
+ * [method@PrintCompositor.paginate] function.
  */
 void
 gtk_source_print_compositor_set_footer_font_name (GtkSourcePrintCompositor *compositor,
@@ -1519,12 +1479,11 @@ gtk_source_print_compositor_set_footer_font_name (GtkSourcePrintCompositor *comp
  * @compositor: a #GtkSourcePrintCompositor.
  *
  * Returns the name of the font used to print the page footer.
+ *
  * The returned string must be freed with g_free().
  *
  * Return value: a new string containing the name of the font used to print
  * the page footer.
- *
- * Since: 2.2
  */
 gchar *
 gtk_source_print_compositor_get_footer_font_name (GtkSourcePrintCompositor *compositor)
@@ -1549,8 +1508,6 @@ gtk_source_print_compositor_get_footer_font_name (GtkSourcePrintCompositor *comp
  * @unit: the units for @margin
  *
  * Sets the top margin used by @compositor.
- *
- * Since: 2.2
  */
 void
 gtk_source_print_compositor_set_top_margin (GtkSourcePrintCompositor *compositor,
@@ -1572,8 +1529,6 @@ gtk_source_print_compositor_set_top_margin (GtkSourcePrintCompositor *compositor
  * Gets the top margin in units of @unit.
  *
  * Return value: the top margin.
- *
- * Since: 2.2
  */
 gdouble
 gtk_source_print_compositor_get_top_margin (GtkSourcePrintCompositor *compositor,
@@ -1593,8 +1548,6 @@ gtk_source_print_compositor_get_top_margin (GtkSourcePrintCompositor *compositor
  * @unit: the units for @margin.
  *
  * Sets the bottom margin used by @compositor.
- *
- * Since: 2.2
  */
 void
 gtk_source_print_compositor_set_bottom_margin (GtkSourcePrintCompositor *compositor,
@@ -1616,8 +1569,6 @@ gtk_source_print_compositor_set_bottom_margin (GtkSourcePrintCompositor *composi
  * Gets the bottom margin in units of @unit.
  *
  * Return value: the bottom margin.
- *
- * Since: 2.2
  */
 gdouble
 gtk_source_print_compositor_get_bottom_margin (GtkSourcePrintCompositor *compositor,
@@ -1637,8 +1588,6 @@ gtk_source_print_compositor_get_bottom_margin (GtkSourcePrintCompositor *composi
  * @unit: the units for @margin.
  *
  * Sets the left margin used by @compositor.
- *
- * Since: 2.2
  */
 void
 gtk_source_print_compositor_set_left_margin (GtkSourcePrintCompositor *compositor,
@@ -1660,8 +1609,6 @@ gtk_source_print_compositor_set_left_margin (GtkSourcePrintCompositor *composito
  * Gets the left margin in units of @unit.
  *
  * Return value: the left margin
- *
- * Since: 2.2
  */
 gdouble
 gtk_source_print_compositor_get_left_margin (GtkSourcePrintCompositor *compositor,
@@ -1681,8 +1628,6 @@ gtk_source_print_compositor_get_left_margin (GtkSourcePrintCompositor *composito
  * @unit: the units for @margin.
  *
  * Sets the right margin used by @compositor.
- *
- * Since: 2.2
  */
 void
 gtk_source_print_compositor_set_right_margin (GtkSourcePrintCompositor *compositor,
@@ -1704,8 +1649,6 @@ gtk_source_print_compositor_set_right_margin (GtkSourcePrintCompositor *composit
  * Gets the right margin in units of @unit.
  *
  * Return value: the right margin.
- *
- * Since: 2.2
  */
 gdouble
 gtk_source_print_compositor_get_right_margin (GtkSourcePrintCompositor *compositor,
@@ -1727,8 +1670,6 @@ gtk_source_print_compositor_get_right_margin (GtkSourcePrintCompositor *composit
  *
  * Return value: the number of pages in the document or <code>-1</code> if the
  * document has not been completely paginated.
- *
- * Since: 2.2
  */
 gint
 gtk_source_print_compositor_get_n_pages (GtkSourcePrintCompositor *compositor)
@@ -2223,22 +2164,12 @@ calculate_page_size_and_margins (GtkSourcePrintCompositor *compositor,
 	                         convert_to_mm (get_text_height (compositor), GTK_UNIT_POINTS));
 }
 
-/* TODO: maybe we should have a public api to set
- * which tags need to be printed and which should not.
- * For now we special case bracket matches.
- */
 static gboolean
 ignore_tag (GtkSourcePrintCompositor *compositor,
             GtkTextTag               *tag)
 {
 	GtkSourcePrintCompositorPrivate *priv = gtk_source_print_compositor_get_instance_private (compositor);
-	GtkTextTag *bm_tag;
-
-	bm_tag = _gtk_source_buffer_get_bracket_match_tag (priv->buffer);
-	if ((bm_tag != NULL) && (tag == bm_tag))
-		return TRUE;
-
-	return FALSE;
+	return tag ? g_hash_table_contains (priv->ignored_tags, tag) : FALSE;
 }
 
 static GSList *
@@ -2495,15 +2426,15 @@ set_pango_layouts_width (GtkSourcePrintCompositor *compositor)
  * Paginate the document associated with the @compositor.
  *
  * In order to support non-blocking pagination, document is paginated in small chunks.
- * Each time gtk_source_print_compositor_paginate() is invoked, a chunk of the document
- * is paginated. To paginate the entire document, gtk_source_print_compositor_paginate()
+ * Each time [method@PrintCompositor.paginate] is invoked, a chunk of the document
+ * is paginated. To paginate the entire document, [method@PrintCompositor.paginate]
  * must be invoked multiple times.
  * It returns %TRUE if the document has been completely paginated, otherwise it returns %FALSE.
  *
- * This method has been designed to be invoked in the handler of the #GtkPrintOperation::paginate signal,
+ * This method has been designed to be invoked in the handler of the [signal@Gtk.PrintOperation::paginate] signal,
  * as shown in the following example:
  *
- * <informalexample><programlisting>
+ * ```c
  * // Signal handler for the GtkPrintOperation::paginate signal
  *
  * static gboolean
@@ -2527,13 +2458,13 @@ set_pango_layouts_width (GtkSourcePrintCompositor *compositor)
  *
  *     return FALSE;
  * }
- * </programlisting></informalexample>
+ * ```
  *
  * If you don't need to do pagination in chunks, you can simply do it all in the
- * #GtkPrintOperation::begin-print handler, and set the number of pages from there, like
+ * [signal@Gtk.PrintOperation::begin-print] handler, and set the number of pages from there, like
  * in the following example:
  *
- * <informalexample><programlisting>
+ * ```c
  * // Signal handler for the GtkPrintOperation::begin-print signal
  *
  * static void
@@ -2551,11 +2482,9 @@ set_pango_layouts_width (GtkSourcePrintCompositor *compositor)
  *     n_pages = gtk_source_print_compositor_get_n_pages (compositor);
  *     gtk_print_operation_set_n_pages (operation, n_pages);
  * }
- * </programlisting></informalexample>
+ * ```
  *
  * Return value: %TRUE if the document has been completely paginated, %FALSE otherwise.
- *
- * Since: 2.2
  */
 gboolean
 gtk_source_print_compositor_paginate (GtkSourcePrintCompositor *compositor,
@@ -2805,8 +2734,6 @@ gtk_source_print_compositor_paginate (GtkSourcePrintCompositor *compositor,
  * Returns the current fraction of the document pagination that has been completed.
  *
  * Return value: a fraction from 0.0 to 1.0 inclusive.
- *
- * Since: 2.2
  */
 gdouble
 gtk_source_print_compositor_get_pagination_progress (GtkSourcePrintCompositor *compositor)
@@ -3094,10 +3021,10 @@ print_footer (GtkSourcePrintCompositor *compositor,
  *
  * Draw page @page_nr for printing on the the Cairo context encapsuled in @context.
  *
- * This method has been designed to be called in the handler of the #GtkPrintOperation::draw_page signal
+ * This method has been designed to be called in the handler of the [signal@Gtk.PrintOperation::draw_page] signal
  * as shown in the following example:
  *
- * <informalexample><programlisting>
+ * ```c
  * // Signal handler for the GtkPrintOperation::draw_page signal
  *
  * static void
@@ -3114,7 +3041,7 @@ print_footer (GtkSourcePrintCompositor *compositor,
  *                                            context,
  *                                            page_nr);
  * }
- * </programlisting></informalexample>
+ * ```
  */
 void
 gtk_source_print_compositor_draw_page (GtkSourcePrintCompositor *compositor,
@@ -3301,3 +3228,28 @@ gtk_source_print_compositor_draw_page (GtkSourcePrintCompositor *compositor,
 		gtk_text_iter_forward_line (&start);
 	}
 }
+
+/**
+ * gtk_source_print_compositor_ignore_tag:
+ * @compositor: a #GtkSourcePrintCompositor
+ * @tag: a #GtkTextTag
+ *
+ * Specifies a tag whose style should be ignored when compositing the
+ * document to the printable page.
+ *
+ * Since: 5.2
+ */
+void
+gtk_source_print_compositor_ignore_tag (GtkSourcePrintCompositor *compositor,
+                                        GtkTextTag               *tag)
+{
+	GtkSourcePrintCompositorPrivate *priv = gtk_source_print_compositor_get_instance_private (compositor);
+
+	g_return_if_fail (GTK_SOURCE_IS_PRINT_COMPOSITOR (compositor));
+	g_return_if_fail (!tag || GTK_IS_TEXT_TAG (tag));
+
+	if (tag != NULL)
+	{
+		g_hash_table_add (priv->ignored_tags, tag);
+	}
+}
