@@ -177,7 +177,7 @@ gtk_source_style_scheme_manager_init (GtkSourceStyleSchemeManager *mgr)
  *
  * Creates a new style manager.
  *
- * If you do not need more than one style manager
+ * If you do not need more than one style manager 
  * then use [func@StyleSchemeManager.get_default] instead.
  *
  * Returns: a new #GtkSourceStyleSchemeManager.
@@ -415,10 +415,6 @@ notify_search_path (GtkSourceStyleSchemeManager *mgr)
  * style scheme files.
  *
  * If @path is %NULL, the search path is reset to default.
- *
- * Since GtkSourceView 5.16 this function will allow you to provide
- * paths in the form of "resource:///" URIs to embedded `GResource`s.
- * They must contain the path of a directory within the `GResource`.
  */
 void
 gtk_source_style_scheme_manager_set_search_path (GtkSourceStyleSchemeManager *manager,
@@ -466,9 +462,9 @@ gtk_source_style_scheme_manager_append_search_path (GtkSourceStyleSchemeManager
 
 	len = g_strv_length (manager->search_path);
 
-	manager->search_path = g_renew (char *,
-	                                manager->search_path,
-	                                len + 2); /* old path + new entry + NULL */
+	manager->search_path = g_renew (gchar *,
+					      manager->search_path,
+					      len + 2); /* old path + new entry + NULL */
 
 	manager->search_path[len] = g_strdup (path);
 	manager->search_path[len + 1] = NULL;
@@ -541,8 +537,8 @@ gtk_source_style_scheme_manager_get_search_path (GtkSourceStyleSchemeManager *ma
  * @manager: a #GtkSourceStyleSchemeManager.
  *
  * Mark any currently cached information about the available style schems
- * as invalid.
- *
+ * as invalid. 
+ * 
  * All the available style schemes will be reloaded next time the @manager is accessed.
  */
 void
