@@ -50,6 +50,12 @@ typedef struct _GtkSourceGutterLines               GtkSourceGutterLines;
 typedef struct _GtkSourceGutterRenderer            GtkSourceGutterRenderer;
 typedef struct _GtkSourceGutterRendererPixbuf      GtkSourceGutterRendererPixbuf;
 typedef struct _GtkSourceGutterRendererText        GtkSourceGutterRendererText;
+typedef struct _GtkSourceHover                     GtkSourceHover;
+typedef struct _GtkSourceHoverContext              GtkSourceHoverContext;
+typedef struct _GtkSourceHoverDisplay              GtkSourceHoverDisplay;
+typedef struct _GtkSourceHoverProvider             GtkSourceHoverProvider;
+typedef struct _GtkSourceVimIMContext              GtkSourceVimIMContext;
+typedef struct _GtkSourceIndenter                  GtkSourceIndenter;
 typedef struct _GtkSourceLanguage                  GtkSourceLanguage;
 typedef struct _GtkSourceLanguageManager           GtkSourceLanguageManager;
 typedef struct _GtkSourceMap                       GtkSourceMap;
@@ -69,6 +75,7 @@ typedef struct _GtkSourceStyleSchemeChooser        GtkSourceStyleSchemeChooser;
 typedef struct _GtkSourceStyleSchemeChooserWidget  GtkSourceStyleSchemeChooserWidget;
 typedef struct _GtkSourceStyleScheme               GtkSourceStyleScheme;
 typedef struct _GtkSourceStyleSchemeManager        GtkSourceStyleSchemeManager;
+typedef struct _GtkSourceStyleSchemePreview        GtkSourceStyleSchemePreview;
 typedef struct _GtkSourceView                      GtkSourceView;
 
 G_END_DECLS
