@@ -30,8 +30,6 @@
 
 #include "config.h"
 
-#define _GNU_SOURCE
-
 #if defined(HAVE_POSIX_MEMALIGN) && !defined(_XOPEN_SOURCE)
 # define _XOPEN_SOURCE 600
 #endif
@@ -57,28 +55,12 @@
 
 #include <glib.h>
 #include <glib/gi18n-lib.h>
-#include <pango/pango.h>
 
-#include "gtksourcetrace.h"
 #include "gtksourceutils.h"
 #include "gtksourceutils-private.h"
 
 #ifdef G_OS_WIN32
-# include <windows.h>
-#endif
-
-#ifdef G_OS_WIN32
-# if PANGO_VERSION_CHECK(1, 52, 0)
-#  include <pango/pangowin32.h>
-#  define FONTLOADING_WITH_PANGOWIN32
-# endif
-#endif
-
-#if ENABLE_FONT_CONFIG
-# include <fontconfig/fontconfig.h>
-# include <pango/pangocairo.h>
-# include <pango/pangofc-fontmap.h>
-# define FONTLOADING_WITH_FONTCONFIG
+#include <windows.h>
 #endif
 
 /**
@@ -254,54 +236,21 @@ _gtk_source_utils_get_default_dirs (const gchar *basename)
 
 	dirs = g_ptr_array_new ();
 
-	/* Priorities are as follows:
-	 *
-	 *  - User data dir
-	 *  - Installation data dir (which allows overriding resources)
-	 *  - Bundled resources
-	 *  - Other data dirs (which sometimes may include other installations)
-	 */
-
 	/* User dir */
 	g_ptr_array_add (dirs, g_build_filename (g_get_user_data_dir (),
-	                                         GSV_DATA_SUBDIR,
-	                                         basename,
-	                                         NULL));
+						 GSV_DATA_SUBDIR,
+						 basename,
+						 NULL));
 
-#ifdef DATADIR
-	/* Our installation data dir */
-	g_ptr_array_add (dirs,
-	                 g_build_filename (DATADIR,
-	                                   GSV_DATA_SUBDIR,
-	                                   basename,
-	                                   NULL));
-#endif
-
-	/* For directories that support resource:// include that next */
-	if (g_str_equal (basename, "styles") ||
-	    g_str_equal (basename, "language-specs") ||
-	    g_str_equal (basename, "snippets"))
-	{
-		g_ptr_array_add (dirs,
-		                 g_strconcat ("resource:///org/gnome/gtksourceview/", basename, "/",
-		                              NULL));
-	}
-
-	/* Rest of the system dirs */
+	/* System dirs */
 	for (system_dirs = g_get_system_data_dirs ();
 	     system_dirs != NULL && *system_dirs != NULL;
 	     system_dirs++)
 	{
-#ifdef DATADIR
-		if (g_str_has_prefix (*system_dirs, DATADIR G_DIR_SEPARATOR_S))
-			continue;
-#endif
-
-		g_ptr_array_add (dirs,
-		                 g_build_filename (*system_dirs,
-		                                   GSV_DATA_SUBDIR,
-		                                   basename,
-		                                   NULL));
+		g_ptr_array_add (dirs, g_build_filename (*system_dirs,
+							 GSV_DATA_SUBDIR,
+							 basename,
+							 NULL));
 	}
 
 	g_ptr_array_add (dirs, NULL);
@@ -1000,168 +949,3 @@ _gtk_source_utils_aligned_free (gpointer data)
 {
 	aligned_free (data);
 }
-
-#if ENABLE_FONT_CONFIG
-static PangoFontMap *
-load_override_font_fc (void)
-{
-	static FcConfig *map_font_config;
-	PangoFontMap *font_map = NULL;
-
-	font_map = pango_cairo_font_map_new_for_font_type (CAIRO_FONT_TYPE_FT);
-
-	if (!font_map)
-	{
-		g_warning ("Unable to create new fontmap");
-		return NULL;
-	}
-
-	if (g_once_init_enter (&map_font_config))
-	{
-		char **font_dirs = _gtk_source_utils_get_default_dirs ("fonts");
-		FcConfig *config = FcConfigCreate ();
-
-		if (font_dirs != NULL)
-		{
-			gboolean found = FALSE;
-
-			for (guint i = 0; !found && font_dirs[i]; i++)
-			{
-				char *font_path = g_build_filename (font_dirs[i], "BuilderBlocks.ttf", NULL);
-
-				if (g_file_test (font_path, G_FILE_TEST_IS_REGULAR))
-				{
-					found = TRUE;
-
-#ifdef G_OS_WIN32
-					/* Reformat the path as expected by win32 FontConfig */
-					FcChar8 *win32_path = FcStrCopyFilename ((const FcChar8 *)font_path);
-					FcConfigAppFontAddFile (config, win32_path);
-					FcStrFree (win32_path);
-#else
-					FcConfigAppFontAddFile (config, (const FcChar8 *)font_path);
-#endif
-				}
-
-				g_free (font_path);
-			}
-		}
-
-		g_strfreev (font_dirs);
-
-		g_once_init_leave (&map_font_config, config);
-	}
-
-	g_assert (map_font_config != NULL);
-
-	pango_fc_font_map_set_config (PANGO_FC_FONT_MAP (font_map), map_font_config);
-
-	return font_map;
-}
-#endif
-
-#ifdef FONTLOADING_WITH_PANGOWIN32
-static PangoFontMap *
-load_override_font_win32 (void)
-{
-	PangoFontMap *font_map;
-	char **font_dirs;
-
-	font_map = pango_cairo_font_map_new_for_font_type (CAIRO_FONT_TYPE_WIN32);
-
-	if (!font_map)
-	{
-		g_error ("Unable to create new fontmap");
-		return NULL;
-	}
-
-	font_dirs = _gtk_source_utils_get_default_dirs ("fonts");
-
-	if (font_dirs != NULL)
-	{
-		for (guint i = 0; font_dirs[i]; i++)
-		{
-			char *font_path = g_build_filename (font_dirs[i], "BuilderBlocks.ttf", NULL);
-
-			if (g_file_test (font_path, G_FILE_TEST_IS_REGULAR))
-			{
-				GError *error = NULL;
-
-				pango_win32_font_map_add_font_file (font_map, font_path, &error);
-
-				if (error)
-				{
-					g_warning("Font loading error: %s", error->message);
-					g_clear_error (&error);
-				}
-			}
-
-			g_free (font_path);
-		}
-	}
-
-	g_strfreev (font_dirs);
-
-	return font_map;
-}
-#endif
-
-PangoFontMap *
-_gtk_source_utils_get_builder_blocks (void)
-{
-	static PangoFontMap *builder_blocks_font_map;
-	static gsize loaded;
-
-	if (g_once_init_enter (&loaded))
-	{
-		GTK_SOURCE_PROFILER_BEGIN_MARK
-#ifdef FONTLOADING_WITH_PANGOWIN32
-		if (builder_blocks_font_map == NULL)
-		{
-			builder_blocks_font_map = load_override_font_win32 ();
-		}
-#endif
-
-#ifdef FONTLOADING_WITH_FONTCONFIG
-		if (builder_blocks_font_map == NULL)
-		{
-			builder_blocks_font_map = load_override_font_fc ();
-		}
-#endif
-		GTK_SOURCE_PROFILER_END_MARK ("Fonts", "Loading BuilderBlocks font...");
-
-		g_once_init_leave (&loaded, TRUE);
-	}
-
-	return builder_blocks_font_map;
-}
-
-gsize
-_gtk_source_utils_strnlen (const char *str,
-			   gsize       maxlen)
-{
-#ifdef HAVE_STRNLEN
-	return strnlen (str, maxlen);
-#else
-	gsize i = 0;
-
-	for (;;)
-	{
-		if (str[i] == 0)
-		{
-			return i;
-		}
-
-		if (i == maxlen)
-		{
-			return maxlen;
-		}
-
-		i++;
-	}
-
-	g_assert_not_reached ();
-
-	return 0;
-#endif
-}
